@@ -230,8 +230,8 @@ class Import(object):
         parser.add_option("-c", "--check-mapping",
                 action="store_true",
                 dest="checkmapping",
-                default=False,
-                help="Check mapping template")
+                default=True,
+                help="Template mapping check (obsolete, always enabled)")
         parser.add_option("-d", "--debug",
                 action="store_true",
                 dest="debug",
@@ -373,6 +373,28 @@ class Import(object):
     def _is_model_defined(self, model):
         return model in self.mapping.keys()
 
+    def _is_readonly(self, model ,field):
+        """Check field requirability
+        
+        :returns: bool
+
+        """
+        res = self.server.execute(self.db, self.uid, self.pwd, model, 'fields_get')
+        if 'readonly' in res:
+            return True
+        return False
+
+    def _is_required(self, model ,field):
+        """Check field requirability
+        
+        :returns: bool
+
+        """
+        res = self.server.execute(self.db, self.uid, self.pwd, model, 'fields_get')
+        if 'required' in res:
+            return True
+        return False
+
     def _is_field(self, model, attr):
         """Check field validity
         
@@ -420,6 +442,8 @@ class Import(object):
                 if model.startswith(self._relationnal_prefix):
                     model = model.split('::')[1]
                     columns = [columns]
+                elif model.startswith('NO_CREATE'):
+                    model = model.split('::')[1]
                 elif model.startswith('NO_UPDATE'):
                     model = model.split('::')[1]
                 
@@ -434,7 +458,7 @@ class Import(object):
 pairs of item and objects (non relationnal) must be in a list.\n\n"
                         res += "=> %s" % error
                     else:
-                        for attr, tuple_val in obj.iteritems():
+                        for attr, tuple_val in obj.items():
                             self._logger.debug("Checking field '%s'" % attr,
                                     extra=STATS)
                             for patt in ACTION_PATTERN.values():
@@ -445,16 +469,18 @@ pairs of item and objects (non relationnal) must be in a list.\n\n"
                                 res += "\t* '%s' '%s' does not exist, \n\n" %\
                                         (model, attr)
                                 continue
+                            column = None
+                            lambda_func = None
+                            searchable = None
                             try:
-                                if callable(tuple_val):
-                                    tuple_val = tuple_val()[0]
-                                (name, lambda_func, searchable) = tuple_val
-                                if name is None and not callable(lambda_func):
-                                    res += "\t* You must indicate either a column\
-number or a function or both in a field definition, \n\n"
+                                (column, lambda_func, searchable) = tuple_val
+                                if column is None and not callable(lambda_func):
+                                    res += "\t* You must indicate either a column number or a function or both in an attribute definition, \n\n"
                             except:
-                                res += "\t* '%s' '%s' definition is not well\
-formed, \n\n" % (model, attr)
+                                res += "\t* '%s' '%s' definition is not well formed, \n\n" % (model, attr)
+
+                            required = self._is_required(model, attr)
+                            obj[attr] = (column, lambda_func, searchable, required)
 
         if res != "":
             raise Exception(title + res)
@@ -699,7 +725,7 @@ formed, \n\n" % (model, attr)
                     id = self._noupdate_relation(model, data_rel, search_rel)
                 
                 if not id:
-                    (state, model, id) = self.create(model.split('::')[1],
+                    (state, model, id) = self.create(model,
                             data_rel, search_rel)
                 data_rel['CREATED::id'] = id
         return id 
@@ -862,12 +888,18 @@ formed, \n\n" % (model, attr)
             current_model = model
 
             if current_model.startswith(self._relationnal_prefix)\
-                    or current_model.startswith('NO_UPDATE'):
+                    or current_model.startswith('NO_UPDATE')\
+                    or current_model.startswith('NO_CREATE'):
                 current_model = model.split('::')[1]
             
             column = -1 # Default
             searchable = False
-            (column, callback, searchable) = tuple_val
+            try:
+                required = False
+                (column, callback, searchable) = tuple_val
+            except:
+                (column, callback, searchable, required) = tuple_val
+
             content = self._get_content(model, column, callback)
             
             if callback is not None:
@@ -901,14 +933,25 @@ formed, \n\n" % (model, attr)
             # Add this item to search criteria
             if searchable:
                 search.append(item)
-            data[item] = content
 
+            # Manage null values
+            #===================================================================
+            try:
+                data[item] = content.strip(' \t\n\r\r\n')
+            except:
+                data[item] = content
             #Cleaning dict items with null value
-            if content in ("", " ", None):
-               ToRemove.append(item)
-           
+            if not data[item]:
+                if required:
+                    raise exceptions.RequiredFieldError('%s %s field is required. Skipped.'\
+                            % (model, item))
+                ToRemove.append(item)
+
+        # Cleaning data from given attributes
         for item in ToRemove:
             del data[item]
+        
+        # Adding this to indicate that this field has been loaded
         data['CREATED::search'] = search
         return search
     
@@ -930,13 +973,26 @@ formed, \n\n" % (model, attr)
         global STATS
         STATS['importfile'] = self._filename
         update = True
+        create = True
         if model.count('NO_UPDATE'):
             update = False
+        if model.count('NO_CREATE'):
+            create = False
         if model.count('::'):
             model = model.split('::')[1]
         res = [False]
         error = None
         state = 'old'
+        
+        # Manage null values
+        for attr, value in data.items():
+            try:
+                data[attr] = value.strip(' \t\n\r\r\n')
+            except:
+                pass
+            if not data[attr]:
+                del data[attr]
+
         search = self.search(model, data, search)
         if 'CREATED::id' in data and data['CREATED::id']:
             res = [int(data['CREATED::id'])]
@@ -947,6 +1003,8 @@ formed, \n\n" % (model, attr)
                 del data['id']
 
             self._logger.debug('<%-25s> data:%s' % (model, data), extra=STATS)
+
+            # If data is empty SKIPPED
             if not data:
                 self._logger.warning("<%-25s> Null values" % model, extra=STATS)
                 STATS['objects'][model]['skipped'] += 1
@@ -955,13 +1013,20 @@ formed, \n\n" % (model, attr)
                 try:
                     if not search:
                         state = "new"
-                        res = [self.server.execute(self.db,
-                            self.uid, self.pwd, model, 'create', data,
-                            {'lang': self.lang})]
-                        self._logger.info("<%-25s> CREATE%s" % (model, res),
-                                extra=STATS)
-                        STATS['object_created'] += 1
-                        STATS['objects'][model]['created'] += 1
+                        if create:
+                            res = [self.server.execute(self.db,
+                                self.uid, self.pwd, model, 'create', data,
+                                {'lang': self.lang})]
+                            self._logger.info("<%-25s> CREATE%s" % (model, res),
+                                    extra=STATS)
+                            STATS['object_created'] += 1
+                            STATS['objects'][model]['created'] += 1
+                        else:
+                            self._logger.info("<%-25s> NO CREATE %s" %\
+                                    (model,
+                                    'name' in data and data['name'] or 'no_name'),
+                                    extra=STATS)
+
                     else:
                         state = 'old'
                         res = search or [False]
@@ -969,10 +1034,15 @@ formed, \n\n" % (model, attr)
                             self.server.execute(self.db,
                                 self.uid, self.pwd, model, 'write', res, data,
                                 {'lang': self.lang})
-                            self._logger.info("<%-25s> WRITE%s"% (model, res),
+                            self._logger.info("<%-25s> UPDATE%s"% (model, res),
                                     extra=STATS)
                             STATS['object_written'] += 1
                             STATS['objects'][model]['written'] += 1
+                        else:
+                            self._logger.info("<%-25s> NO UPDATE %s" %\
+                                    (model,
+                                    'name' in data and data['name'] or 'no_name'),
+                                    extra=STATS)
                     
                 except xmlrpclib.Fault as err:
                     try:
