@@ -121,10 +121,11 @@ def get_value_from_table(csv_file, col_referer=0, col_return=1,
 
     return _get_value_from_table
 
-def get_ids(args, model, field):
+def get_ids(args, model, fields, op='&'):
     """Return ``model`` which ``fields``'s value matched ``args[3]`` value
    
-    >>> 'partner_ids': Column(56, get_ids('res.partner.address', 'city'))
+    >>> 'partner_ids': Column(56, get_ids('res.partner.address', ['street', 'street2'], op='|'))
+    [100, 102]
     
     :param args: lambda args (ie: [self, model ,field, content, line])
     :type args: list
@@ -137,24 +138,35 @@ def get_ids(args, model, field):
     :returns: list
 
     """
-    def _get_ids(self, model, field, value, line):
-
+    def _get_ids(self, b_model, b_field, b_value, b_line):
+        print self, b_model, b_field, b_value, b_line
+        search = []
         try:
-            value = value.strip()
-        except:
+            b_value = str(b_value).strip()
+        except Exception:
             pass
-        res = self.search(model, {field: value}, [field])
-        if not res:
-            self.logger.warning(u'get_ids(%s, %s): No object found for value `%s` on model' %
-                    (model, field, value), extra=STATS)
-        return res
+        i = 1
+        for field in fields:
+            if i != len(fields):
+                search.append(op)
+                i += 1
+            search.append((field, '=', b_value))
+        print search
 
+        res = self.server.execute(self.db, self.uid, self.pwd,
+               model, 'search', search) 
+        if not res:
+            self._logger.warning(u'get_ids(%s, %s): no object found for value `%s` on model' %
+                    (model, fields, b_value), extra=STATS)
+        return res
+    
     return _get_ids
 
-def get_id(model, field):
+def get_id(model, fields, op='&'):
     """Return ``model`` which ``fields``'s value matched ``args[3]`` value
    
-    >>> 'address_ids': (21, get_ids('res.partner', 'city'))
+    >>> 'address_ids': (21, get_ids('res.partner', ['name']))
+    [99]
     
     :param args: lambda args (ie: [self, model ,field, content, line])
     :type args: list
@@ -168,7 +180,7 @@ def get_id(model, field):
 
     """
     def _get_id(*args): 
-        res = get_ids(model, field)(*args)
+        res = get_ids(model, fields, op)(*args)
         return res and res[0] or False
     
     return _get_id
