@@ -37,6 +37,24 @@ Exceptions used in csv2oerp.
 
 from constants_and_vars import STATS
 
+class RequiredFieldError(IndexError):
+    """Exception used when a column index has not be found 
+    
+    """
+    def __init__(self, model, field, log=None):
+        """
+        :param model: Object model
+        :type model: str
+        :param field: Field required
+        :type field: str
+
+        """
+        msg = "Required model(%s) field(%s) has null value. Skipping." % (model, field)
+        if log:
+            log.info("<%-20s> %s" % msg, extra=STATS)
+        super(RequiredFieldError, self).__init__(msg)
+
+
 class ColumnIndexError(IndexError):
     """Exception used when a column index has not be found 
     
